pub fn get_diff_files(base_commit: &str) -> DiffResultExpand description
Get files modified since a given commit using git diff-tree.
pub fn get_diff_files(base_commit: &str) -> DiffResultGet files modified since a given commit using git diff-tree.