pub fn parse_transcript(path: &Path) -> TranscriptAnalysisExpand description
Parse a Claude Code transcript file and extract token usage and metadata. Deduplicates by message.id (Claude streams may create multiple entries).
pub fn parse_transcript(path: &Path) -> TranscriptAnalysisParse a Claude Code transcript file and extract token usage and metadata. Deduplicates by message.id (Claude streams may create multiple entries).